"use strict";
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypescriptCodeGenerator = exports.GENERATORS = void 0;
var AccessorDeclaration_1 = require("../declarations/AccessorDeclaration");
var MethodDeclaration_1 = require("../declarations/MethodDeclaration");
var ParameterDeclaration_1 = require("../declarations/ParameterDeclaration");
var PropertyDeclaration_1 = require("../declarations/PropertyDeclaration");
var VariableDeclaration_1 = require("../declarations/VariableDeclaration");
var NotGeneratableYetError_1 = require("../errors/NotGeneratableYetError");
var ExternalModuleImport_1 = require("../imports/ExternalModuleImport");
var NamedImport_1 = require("../imports/NamedImport");
var NamespaceImport_1 = require("../imports/NamespaceImport");
var StringImport_1 = require("../imports/StringImport");
var SymbolSpecifier_1 = require("../SymbolSpecifier");
var accessorDeclaration_1 = require("./typescript-generators/accessorDeclaration");
var externalModuleImport_1 = require("./typescript-generators/externalModuleImport");
var methodDeclaration_1 = require("./typescript-generators/methodDeclaration");
var namedImport_1 = require("./typescript-generators/namedImport");
var namespaceImport_1 = require("./typescript-generators/namespaceImport");
var parameterDeclaration_1 = require("./typescript-generators/parameterDeclaration");
var propertyDeclaration_1 = require("./typescript-generators/propertyDeclaration");
var stringImport_1 = require("./typescript-generators/stringImport");
var symbolSpecifier_1 = require("./typescript-generators/symbolSpecifier");
var variableDeclaration_1 = require("./typescript-generators/variableDeclaration");
/**
 * Hash with all possible (yet implemented) generators.
 */
exports.GENERATORS = (_a = {},
    _a[SymbolSpecifier_1.SymbolSpecifier.name] = symbolSpecifier_1.generateSymbolSpecifier,
    _a[MethodDeclaration_1.MethodDeclaration.name] = methodDeclaration_1.generateMethodDeclaration,
    _a[ParameterDeclaration_1.ParameterDeclaration.name] = parameterDeclaration_1.generateParameterDeclaration,
    _a[PropertyDeclaration_1.PropertyDeclaration.name] = propertyDeclaration_1.generatePropertyDeclaration,
    _a[VariableDeclaration_1.VariableDeclaration.name] = variableDeclaration_1.generateVariableDelcaration,
    _a[ExternalModuleImport_1.ExternalModuleImport.name] = externalModuleImport_1.generateExternalModuleImport,
    _a[NamedImport_1.NamedImport.name] = namedImport_1.generateNamedImport,
    _a[NamespaceImport_1.NamespaceImport.name] = namespaceImport_1.generateNamespaceImport,
    _a[StringImport_1.StringImport.name] = stringImport_1.generateStringImport,
    _a[AccessorDeclaration_1.SetterDeclaration.name] = accessorDeclaration_1.generateAccessorDeclaration,
    _a[AccessorDeclaration_1.GetterDeclaration.name] = accessorDeclaration_1.generateAccessorDeclaration,
    _a);
/**
 * Generator for typescript code elements. Takes a generatable object and tries to generate typescript code.
 *
 * @export
 * @class TypescriptCodeGenerator
 */
var TypescriptCodeGenerator = /** @class */ (function () {
    function TypescriptCodeGenerator(options) {
        this.options = options;
    }
    /**
     * Generator function. Calls the specific element generator. If no generator is found, an exception is thrown.
     *
     * @param {Generatable} declaration
     * @returns {string}
     * @throws {NotGeneratableYetError}
     * @memberof TypescriptCodeGenerator
     */
    TypescriptCodeGenerator.prototype.generate = function (declaration) {
        if (exports.GENERATORS[declaration.constructor.name]) {
            return exports.GENERATORS[declaration.constructor.name](declaration, this.options);
        }
        throw new NotGeneratableYetError_1.NotGeneratableYetError(declaration);
    };
    return TypescriptCodeGenerator;
}());
exports.TypescriptCodeGenerator = TypescriptCodeGenerator;
