"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateNamedImport = void 0;
var tslib_1 = require("tslib");
var StringTemplate_1 = require("../../utilities/StringTemplate");
var TypescriptGenerationOptions_1 = require("../TypescriptGenerationOptions");
var symbolSpecifier_1 = require("./symbolSpecifier");
var oneLinerImportTemplate = StringTemplate_1.stringTemplate(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["import ", " from ", ""], ["import ", " from ", ""])), 0, 1);
var multiLineImportTemplate = StringTemplate_1.stringTemplate(templateObject_2 || (templateObject_2 = tslib_1.__makeTemplateObject(["import ", "{\n", "", "\n} from ", ""], ["import ", "{\n", "", "\n} from ", ""])), 3, 0, 1, 2);
var defaultAliasOnlyMultiLineImportTemplate = StringTemplate_1.stringTemplate(templateObject_3 || (templateObject_3 = tslib_1.__makeTemplateObject(["import ", "\nfrom ", ""], ["import ", "\nfrom ", ""])), 0, 1);
/**
 * Sort function for symbol specifiers. Does sort after the specifiers name (to lowercase).
 *
 * @param {SymbolSpecifier} i1
 * @param {SymbolSpecifier} i2
 * @returns {number}
 */
function specifierSort(i1, i2) {
    var strA = i1.specifier.toLowerCase();
    var strB = i2.specifier.toLowerCase();
    if (strA < strB) {
        return -1;
    }
    if (strA > strB) {
        return 1;
    }
    return 0;
}
/**
 * Generates typescript code for a named import.
 *
 * @export
 * @param {NamedImport} imp
 * @param {TypescriptGenerationOptions} { stringQuoteStyle, eol }
 * @returns {string}
 */
function generateNamedImport(imp, _a) {
    var eol = _a.eol, stringQuoteStyle = _a.stringQuoteStyle, spaceBraces = _a.spaceBraces, tabSize = _a.tabSize, wrapMethod = _a.wrapMethod, multiLineWrapThreshold = _a.multiLineWrapThreshold, multiLineTrailingComma = _a.multiLineTrailingComma, _b = _a.insertSpaces, insertSpaces = _b === void 0 ? true : _b;
    var lib = "" + stringQuoteStyle + imp.libraryName + stringQuoteStyle + eol;
    // const specifiers = imp.specifiers.sort(specifierSort).map(o => generateSymbolSpecifier(o)).join(', ');
    var oneLinerImportStatement = oneLinerImportTemplate(getImportSpecifiers(imp, spaceBraces), lib);
    if (oneLinerImportStatement.length <= multiLineWrapThreshold &&
        (wrapMethod !== TypescriptGenerationOptions_1.MultiLineImportRule.strictlyOneImportPerLine ||
            imp.specifiers.length <= 1)) {
        return oneLinerImportStatement;
    }
    var defaultAliasOnly = imp.specifiers.length === 0;
    if (defaultAliasOnly) {
        return defaultAliasOnlyMultiLineImportTemplate(imp.defaultAlias ? imp.defaultAlias + ", " : '', "" + stringQuoteStyle + imp.libraryName + stringQuoteStyle + eol);
    }
    var sortedImportSpecifiers = imp.specifiers.sort(specifierSort);
    var importSpecifierStrings = '';
    var indent = insertSpaces ? Array(tabSize + 1).join(' ') : '\t';
    if (wrapMethod === TypescriptGenerationOptions_1.MultiLineImportRule.strictlyOneImportPerLine ||
        wrapMethod === TypescriptGenerationOptions_1.MultiLineImportRule.oneImportPerLineOnlyAfterThreshold) {
        importSpecifierStrings = sortedImportSpecifiers.map(function (o) { return "" + indent + symbolSpecifier_1.generateSymbolSpecifier(o); }).join(',\n');
    }
    else if (wrapMethod === TypescriptGenerationOptions_1.MultiLineImportRule.multipleImportsPerLine) {
        importSpecifierStrings = sortedImportSpecifiers.reduce(function (acc, curr) {
            var symbolSpecifier = symbolSpecifier_1.generateSymbolSpecifier(curr);
            // const dist: number = acc.out.length - acc.lastWrapOffset + symbolSpecifier.length;
            var importLines = acc.out.split('\n');
            var lastImportLine = importLines[importLines.length - 1];
            var dist = lastImportLine.length + ", ".length + symbolSpecifier.length;
            var needsWrap = dist >= multiLineWrapThreshold;
            return {
                out: acc.out + (needsWrap ? ",\n" + indent : (acc.out.length ? ", " : "" + indent)) +
                    symbolSpecifier,
                lastWrapOffset: acc.lastWrapOffset + (needsWrap ? dist : 0),
            };
        }, {
            out: '',
            lastWrapOffset: 0,
        }).out;
    }
    return multiLineImportTemplate(importSpecifierStrings, multiLineTrailingComma ? ',' : '', "" + stringQuoteStyle + imp.libraryName + stringQuoteStyle + eol, imp.defaultAlias ? imp.defaultAlias + ", " : '');
}
exports.generateNamedImport = generateNamedImport;
function getImportSpecifiers(namedImport, spaceBraces) {
    if (namedImport.defaultAlias && namedImport.specifiers.length <= 0) {
        return namedImport.defaultAlias;
    }
    var space = spaceBraces ? ' ' : '';
    var specifiers = namedImport.specifiers.sort(specifierSort).map(function (o) { return symbolSpecifier_1.generateSymbolSpecifier(o); }).join(', ');
    var importSpecifiers = "" + space + specifiers + space;
    if (importSpecifiers.trim().length === 0) {
        importSpecifiers = ' ';
    }
    if (namedImport.defaultAlias && namedImport.specifiers.length > 0) {
        return namedImport.defaultAlias + ", {" + importSpecifiers + "}";
    }
    return "{" + importSpecifiers + "}";
}
var templateObject_1, templateObject_2, templateObject_3;
