"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NamedImport = void 0;
/**
 * Basic typescript import (ES6 style). Does contain multiple symbols of a file and converts
 * itself to a multiline import if the threshold is reached.
 * Can also contain a default import part.
 * (i.e. import {Foobar} from ...).
 *
 * @export
 * @class NamedImport
 * @implements {Import}
 */
var NamedImport = /** @class */ (function () {
    function NamedImport(libraryName, start, end) {
        this.libraryName = libraryName;
        this.start = start;
        this.end = end;
        this.specifiers = [];
    }
    Object.defineProperty(NamedImport.prototype, "isNew", {
        get: function () {
            return this.start === undefined || this.end === undefined;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Clone the current import object.
     *
     * @returns {NamedImport}
     *
     * @memberof NamedImport
     */
    NamedImport.prototype.clone = function () {
        var clone = new NamedImport(this.libraryName, this.start, this.end);
        clone.specifiers = this.specifiers.map(function (o) { return o.clone(); });
        clone.defaultAlias = this.defaultAlias;
        return clone;
    };
    return NamedImport;
}());
exports.NamedImport = NamedImport;
