"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseExport = void 0;
var DefaultDeclaration_1 = require("../declarations/DefaultDeclaration");
var AllExport_1 = require("../exports/AllExport");
var AssignedExport_1 = require("../exports/AssignedExport");
var NamedExport_1 = require("../exports/NamedExport");
var SymbolSpecifier_1 = require("../SymbolSpecifier");
var TypescriptGuards_1 = require("../type-guards/TypescriptGuards");
var parse_utilities_1 = require("./parse-utilities");
/**
 * Parses an export node into the declaration.
 *
 * @export
 * @param {Resource} resource
 * @param {(ExportDeclaration | ExportAssignment)} node
 */
function parseExport(resource, node) {
    if (TypescriptGuards_1.isExportDeclaration(node)) {
        var tsExport = node;
        if (!TypescriptGuards_1.isStringLiteral(tsExport.moduleSpecifier) && !tsExport.exportClause) {
            return;
        }
        if (tsExport.getText().indexOf('*') > -1) {
            resource.exports.push(new AllExport_1.AllExport(node.getStart(), node.getEnd(), tsExport.moduleSpecifier.text));
        }
        else if (tsExport.exportClause && TypescriptGuards_1.isNamedExports(tsExport.exportClause)) {
            var lib = tsExport.moduleSpecifier;
            var ex = new NamedExport_1.NamedExport(node.getStart(), node.getEnd(), lib ? lib.text : parse_utilities_1.getDefaultResourceIdentifier(resource));
            ex.specifiers = tsExport.exportClause.elements.map(function (o) { return o.propertyName && o.name ?
                new SymbolSpecifier_1.SymbolSpecifier(o.propertyName.text, o.name.text) :
                new SymbolSpecifier_1.SymbolSpecifier(o.name.text); });
            for (var _i = 0, _a = ex.specifiers; _i < _a.length; _i++) {
                var spec = _a[_i];
                if (resource.usages.indexOf(spec.alias || spec.specifier) === -1) {
                    resource.usages.push(spec.alias || spec.specifier);
                }
            }
            resource.exports.push(ex);
        }
    }
    else {
        var literal = node.expression;
        if (node.isExportEquals) {
            resource.exports.push(new AssignedExport_1.AssignedExport(node.getStart(), node.getEnd(), literal.text, resource));
            if (resource.usages.indexOf(literal.text) === -1) {
                resource.usages.push(literal.text);
            }
        }
        else {
            var name_1 = (literal && literal.text) ? literal.text : parse_utilities_1.getDefaultResourceIdentifier(resource);
            if (resource.usages.indexOf(name_1) === -1) {
                resource.usages.push(name_1);
            }
            resource.declarations.push(new DefaultDeclaration_1.DefaultDeclaration(name_1, resource));
        }
    }
}
exports.parseExport = parseExport;
