"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseVariable = void 0;
var typescript_1 = require("typescript");
var VariableDeclaration_1 = require("../declarations/VariableDeclaration");
var TypescriptHeroGuards_1 = require("../type-guards/TypescriptHeroGuards");
var parse_utilities_1 = require("./parse-utilities");
/**
 * Parse a variable. Information such as "is the variable const" are calculated here.
 *
 * @export
 * @param {(Resource | CallableDeclaration)} parent
 * @param {VariableStatement} node
 */
function parseVariable(parent, node) {
    var isConst = node.declarationList.getChildren().some(function (o) { return o.kind === typescript_1.SyntaxKind.ConstKeyword; });
    if (node.declarationList && node.declarationList.declarations) {
        node.declarationList.declarations.forEach(function (o) {
            var declaration = new VariableDeclaration_1.VariableDeclaration(o.name.getText(), isConst, parse_utilities_1.isNodeExported(node), parse_utilities_1.getNodeType(o.type), node.getStart(), node.getEnd());
            if (TypescriptHeroGuards_1.isCallableDeclaration(parent)) {
                parent.variables.push(declaration);
            }
            else {
                parent.declarations.push(declaration);
            }
        });
    }
}
exports.parseVariable = parseVariable;
