"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.File = void 0;
var path_1 = require("path");
var PathHelpers_1 = require("../utilities/PathHelpers");
var Module_1 = require("./Module");
var Namespace_1 = require("./Namespace");
/**
 * TypeScript resource. Basically a file that is located somewhere.
 *
 * @export
 * @class File
 * @implements {Resource}
 * @implements {Node}
 */
var File = /** @class */ (function () {
    function File(filePath, rootPath, start, end) {
        this.filePath = filePath;
        this.rootPath = rootPath;
        this.start = start;
        this.end = end;
        this.imports = [];
        this.exports = [];
        this.declarations = [];
        this.resources = [];
        this.usages = [];
    }
    Object.defineProperty(File.prototype, "identifier", {
        get: function () {
            return '/' + PathHelpers_1.normalizeFilename(path_1.relative(this.rootPath, this.filePath));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(File.prototype, "nonLocalUsages", {
        get: function () {
            var _this = this;
            return this.usages
                .filter(function (usage) {
                return !_this.declarations.some(function (o) { return o.name === usage; }) &&
                    !_this.resources.some(function (o) { return (o instanceof Module_1.Module || o instanceof Namespace_1.Namespace) && o.name === usage; });
            })
                .concat(this.resources.reduce(function (all, cur) { return all.concat(cur.nonLocalUsages); }, []));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(File.prototype, "parsedPath", {
        /**
         * Returns the parsed path of a resource.
         *
         * @readonly
         * @type {ParsedPath}
         * @memberof File
         */
        get: function () {
            return path_1.parse(this.filePath);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(File.prototype, "isWorkspaceFile", {
        /**
         * Determines if a file is a workspace file or an external resource.
         *
         * @readonly
         * @type {boolean}
         * @memberof File
         */
        get: function () {
            var _this = this;
            return ['node_modules', 'typings'].every(function (o) { return _this.filePath.indexOf(o) === -1; });
        },
        enumerable: false,
        configurable: true
    });
    return File;
}());
exports.File = File;
