"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Module = void 0;
var Namespace_1 = require("./Namespace");
/**
 * TypeScript resource. Declaration of a typescript module (i.e. declare module "foobar").
 *
 * @export
 * @class Module
 * @implements {Resource}
 * @implements {Node}
 */
var Module = /** @class */ (function () {
    function Module(name, start, end) {
        this.name = name;
        this.start = start;
        this.end = end;
        this.imports = [];
        this.exports = [];
        this.declarations = [];
        this.resources = [];
        this.usages = [];
    }
    Object.defineProperty(Module.prototype, "identifier", {
        get: function () {
            return this.name;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Module.prototype, "nonLocalUsages", {
        get: function () {
            var _this = this;
            return this.usages
                .filter(function (usage) {
                return !_this.declarations.some(function (o) { return o.name === usage; }) &&
                    !_this.resources.some(function (o) { return (o instanceof Module || o instanceof Namespace_1.Namespace) && o.name === usage; });
            })
                .concat(this.resources.reduce(function (all, cur) { return all.concat(cur.nonLocalUsages); }, []));
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Function that calculates the alias name of a namespace.
     * Removes all underlines and dashes and camelcases the name.
     *
     * @returns {string}
     *
     * @memberof Module
     */
    Module.prototype.getNamespaceAlias = function () {
        return this.name.split(/[-_]/).reduce(function (all, cur, idx) {
            if (idx === 0) {
                return all + cur.toLowerCase();
            }
            return all + cur.charAt(0).toUpperCase() + cur.substring(1).toLowerCase();
        }, '');
    };
    return Module;
}());
exports.Module = Module;
