"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Namespace = void 0;
var Module_1 = require("./Module");
/**
 * TypeScript resource. Declaration of a typescript namespace (i.e. declare foobar).
 *
 * @export
 * @class Namespace
 * @implements {Resource}
 * @implements {Node}
 */
var Namespace = /** @class */ (function () {
    function Namespace(name, start, end) {
        this.name = name;
        this.start = start;
        this.end = end;
        this.imports = [];
        this.exports = [];
        this.declarations = [];
        this.resources = [];
        this.usages = [];
    }
    Object.defineProperty(Namespace.prototype, "identifier", {
        get: function () {
            return this.name;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Namespace.prototype, "nonLocalUsages", {
        get: function () {
            var _this = this;
            return this.usages
                .filter(function (usage) {
                return !_this.declarations.some(function (o) { return o.name === usage; }) &&
                    !_this.resources.some(function (o) { return (o instanceof Module_1.Module || o instanceof Namespace) && o.name === usage; });
            })
                .concat(this.resources.reduce(function (all, cur) { return all.concat(cur.nonLocalUsages); }, []));
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Function that calculates the alias name of a namespace.
     * Removes all underlines and dashes and camelcases the name.
     *
     * @returns {string}
     *
     * @memberof Namespace
     */
    Namespace.prototype.getNamespaceAlias = function () {
        return this.name.split(/[-_]/).reduce(function (all, cur, idx) {
            if (idx === 0) {
                return all + cur.toLowerCase();
            }
            return all + cur.charAt(0).toUpperCase() + cur.substring(1).toLowerCase();
        }, '');
    };
    return Namespace;
}());
exports.Namespace = Namespace;
